@@ -560,16 +560,18 @@ class Compiler:
     @annotate_errors
     def compile_interpolatenode(self, srcnode, parent, mode='yield'):
         value = parse_and_strip(u'x = ({})'.format(srcnode.value))[0].value
-        if not srcnode.autoescape:
-            parent.body.append(
-                self.annotate_runtime_errors(Expr(value=Yield(value)),
-                                             srcnode))
-            return
-        escaped = Call(func=Name(id='__piglet_escape', ctx=Load()),
-                       args=[value],
-                       starargs=None,
-                       kwargs=None,
-                       keywords=[])
+        if srcnode.autoescape:
+            escaped = Call(func=Name(id='__piglet_escape', ctx=Load()),
+                           args=[value],
+                           starargs=None,
+                           kwargs=None,
+                           keywords=[])
+        else:
+            escaped = Call(func=Name(id='str', ctx=Load()),
+                        args=[value],
+                        starargs=None,
+                        kwargs=None,
+                        keywords=[])
 
         parent.body.append(self.annotate_runtime_errors(
             Expr(value=Yield(escaped)), srcnode))
