@@ -185,6 +185,12 @@ class TestTemplate:
         s = t.render({})
         assert s == 'foo: baz'
 
+    def test_unescaped_function_calls_dont_raise_an_error(self):
+        tt = Template('<py:def function="foo">$!{bar()}</py:def>'
+                      '<py:def function="bar">x</py:def>'
+                      '$!{foo()}')
+        assert tt.render({}) == 'x'
+
     def test_it_compiles_pyattrs(self):
         t = Template('<a py:attrs="{\'class\': None, \'href\': \'#\'}">x</a>')
         s = t.render({})
